=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2009-02-26 17:50:46 +0000
+++ loggerhead/controllers/annotate_ui.py	2009-03-01 19:21:18 +0000
@@ -26,7 +26,7 @@
 from paste.httpexceptions import HTTPBadRequest, HTTPServerError
 
 from loggerhead.controllers import TemplatedBranchView
-from loggerhead.highlight import PygmentsHighlighter
+from loggerhead.highlight import pygments_highlight
 from loggerhead import util
 
 
@@ -50,8 +50,7 @@
 
             bzrlib.textfile.check_text_lines(file_lines)
 
-	    hl_lines = PygmentsHighlighter.highlight(file_name, 
-						     ''.join(file_lines))
+	    hl_lines = pygments_highlight(file_name, ''.join(file_lines))
         except bzrlib.errors.BinaryFile:
                 # bail out; this isn't displayable text
                 yield util.Container(parity=0, lineno=1, status='same',

=== modified file 'loggerhead/highlight.py'
--- loggerhead/highlight.py	2009-02-26 17:50:46 +0000
+++ loggerhead/highlight.py	2009-03-01 19:21:18 +0000
@@ -26,39 +26,41 @@
 DEFAULT_PYGMENT_STYLE = 'colorful'
 
 
-class PygmentsHighlighter:
-    @staticmethod
-    def highlight(path, text, style=DEFAULT_PYGMENT_STYLE):
-	""" 
-	Returns a list of highlighted (i.e. HTML formatted) strings and it
-	replaces initial spaces with nonbreaking spaces to maintain
-	indentation.
-	"""
+def pygments_highlight(path, text, style=DEFAULT_PYGMENT_STYLE):
+    """ 
+    Returns a list of highlighted (i.e. HTML formatted) strings and it
+    replaces initial spaces with nonbreaking spaces to maintain
+    indentation.
+    """
 
-	formatter = PygmentsHtmlFormatter(style=style)
+    formatter = PygmentsHtmlFormatter(style=style)
 	
-	encoding = 'utf-8'
-	try:
-	    text = text.decode(encoding)
-	except UnicodeDecodeError:
-	    text = text.decode(encoding)
-	    encoding = 'iso-8859-15'
+    encoding = 'utf-8'
+    try:
+	text = text.decode(encoding)
+    except UnicodeDecodeError:
+	text = text.decode(encoding)
+	encoding = 'iso-8859-15'
 
-	try:
-	    lexer = guess_lexer_for_filename(path, text, encoding=encoding)
+    try:
+	lexer = guess_lexer_for_filename(path, text, encoding=encoding)
+    except (ClassNotFound, ValueError):
+	try: 
+	    lexer = guess_lexer(text, encoding=encoding)
 	except (ClassNotFound, ValueError):
-	    try: 
-		lexer = guess_lexer(text, encoding=encoding)
-	    except (ClassNotFound, ValueError):
-		lexer = TextLexer(encoding=encoding)
-
-	hl_lines = highlight(text, lexer, formatter).split('\n')
-	hl_lines = [ util.fix_whitespace(line) for line in hl_lines ]
-
-	return hl_lines
+	    lexer = TextLexer(encoding=encoding)
+
+    hl_lines = highlight(text, lexer, formatter).split('\n')
+    hl_lines = [ util.fix_whitespace(line) for line in hl_lines ]
+
+    return hl_lines
 
 
 class PygmentsHtmlFormatter(HtmlFormatter):
+    """
+    Custom HTML formatter to avoid default <div> and <pre> blocks.
+    """
+
     def wrap(self, source, outfile):
 	return self._wrap_code(source)
 

